package jwtcreds
import "google.golang.org/grpc/internal/xds/bootstrap/jwtcreds"
Package jwtcreds implements JWT CallCredentials for XDS, configured via xDS Bootstrap File. For more details, see gRFC A97: https://github.com/grpc/proposal/blob/master/A97-xds-jwt-call-creds.md
Index ¶
Functions ¶
func NewCallCredentials ¶
func NewCallCredentials(configJSON json.RawMessage) (c credentials.PerRPCCredentials, cancel func(), err error)
NewCallCredentials returns a new JWT token based call credentials. The input config must match the structure specified in gRFC A97.
The caller is expected to invoke the cancel function when they are done using the returned call creds. This cancel function is idempotent.
Source Files ¶
call_creds.go
- Version
- v1.81.0-dev
- Published
- Mar 6, 2026
- Platform
- linux/amd64
- Imports
- 4 packages
- Last checked
- 1 minute ago –
Tools for package owners.